package com.bocloud.cmp.model.storage;

import java.util.Date;

/**
 * 存储端口的性能统计
 */
public class StatsPortModel {
    private String type; // 类型
    private String providerKey; // 名称 + provider id
    private String sampleInterval; // Some statistics are sampled at consistent time intervals
    private Date statsTime; // 统计进行的时间
    private Date startStatsTime; // The time, relative to managed element where the statistic was collected
    private Double packetsTransmitted;
    private Double packetsReceived;
    private Double bytesTransmitted; // The total number of bytes that are transmitted
    private Double bytesReceived; // The total number of bytes that are received
    private Double lipCount; // the number of LIP events that have occurred on an arbitrated loop.
    private Double nosCount; // the number of NOS events that have occurred on the switched fabric.
    private Double errorFrames;
    private Double dumpedFrames; // the number of frames that were lost due to a lack of host buffers available.
    private Double linkFailures; // the number of times that a link error has occurred.
    private Double lossSignalCounter; // Number of times the signal is lost on the Port
    private Double lossSyncCounter; // Number of times that synchronization is lost on the Port
    private Double primitiveSeqProtocolErrCount; // Count of primitive sequence protocol errors that are detected at this port
    private Double crcErrors; // CRC: computed by the receiver. Number of times that the CRC in a frame does not match the CRC
    private Double invalidTransmissionWords; // The number of transmission words that had an invalid character
    private Double framesToolShort; // The number of frames received that were shorter than 28 octets
    private Double framesToolLong; // The number of frames received that were longer than 2140 octets
    private Double addressErrors; // Count of frames received with unknown addressing
    private Double bufferCreditNotProvided; // Count of occurrences when all input buffers of a port were full and outbound buffer-to-buffer credit was transitioned to zero.
    private Double bufferCreditNotReceived; // Count of transitions in or out of BBcredit zero state.
    private Double bbcreditZeroTime; // Zero buffer-buffer credit timer in microseconds.
    private Double delimiterErrors; // Count of invalid frame delimiters that are received at this port.
    private Double encodingDisparityErrors; // Count of disparity errors that are received at this port.
    private Double linkResetsReceived; // the number of LRs received
    private Double linkResetsTransmitted; // the number of LRs transmitted
    private Double multicastFramesReceived; // Count of Multicast Frames or Packets received
    private Double multicastFramesTransmitted; // Count of Multicast Frames or Packets transmitted
    private Double fbsyFrames; // the number of times that FBSY was returned to the port
    private Double pbsyFrames; // the number of times that PBSY was returned to the port
    private Double frjtFrames; // the number of times that FRJT was returned to the port
    private Double prjtFrames; // the number of times that PRJT was returned to the port
    private Double rxclass1Frames; // the number of class 1 frames received.
    private Double txclass1Frames; // the number of class 1 frames transmitted.
    private Double class1Fbsy; // the number of times that FBSY was returned to the port
    private Double class1Pbsy; // the number of times that PBSY was returned to the port
    private Double class1Frjt; // the number of times that FRJT was returned to the port
    private Double class1Prjt; // the number of times that PRJT was returned to the port
    private Double rxclass2Frames; // the number of class 2 frames received.
    private Double txclass2Frames; // the number of class 2 frames transmitted.
    private Double class2Fbsy; // the number of times that FBSY was returned to the port
    private Double class2Pbsy; // the number of times that PBSY was returned to the port
    private Double class2Frjt; // the number of times that FRJT was returned to the port
    private Double class2Prjt; // the number of times that PRJT was returned to the port
    private Double rxclass3Frames; // the number of class 3 frames received.
    private Double txclass3Frames; // the number of class 3 frames transmitted.
    private Double class3FramesDiscarded; // the number of class 3 frames that were discarded
    private Double rxbroadcastFrames; // the number of broadcast frames or packets received
    private Double txbroadcastFrames; // the number of broadcast frames or packets transmitted

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getProviderKey() {
        return providerKey;
    }

    public void setProviderKey(String providerKey) {
        this.providerKey = providerKey;
    }

    public String getSampleInterval() {
        return sampleInterval;
    }

    public void setSampleInterval(String sampleInterval) {
        this.sampleInterval = sampleInterval;
    }

    public Date getStatsTime() {
        return statsTime;
    }

    public void setStatsTime(Date statsTime) {
        this.statsTime = statsTime;
    }

    public Date getStartStatsTime() {
        return startStatsTime;
    }

    public void setStartStatsTime(Date startStatsTime) {
        this.startStatsTime = startStatsTime;
    }

    public Double getPacketsTransmitted() {
        return packetsTransmitted;
    }

    public void setPacketsTransmitted(Double packetsTransmitted) {
        this.packetsTransmitted = packetsTransmitted;
    }

    public Double getPacketsReceived() {
        return packetsReceived;
    }

    public void setPacketsReceived(Double packetsReceived) {
        this.packetsReceived = packetsReceived;
    }

    public Double getBytesTransmitted() {
        return bytesTransmitted;
    }

    public void setBytesTransmitted(Double bytesTransmitted) {
        this.bytesTransmitted = bytesTransmitted;
    }

    public Double getBytesReceived() {
        return bytesReceived;
    }

    public void setBytesReceived(Double bytesReceived) {
        this.bytesReceived = bytesReceived;
    }

    public Double getLipCount() {
        return lipCount;
    }

    public void setLipCount(Double lipCount) {
        this.lipCount = lipCount;
    }

    public Double getNosCount() {
        return nosCount;
    }

    public void setNosCount(Double nosCount) {
        this.nosCount = nosCount;
    }

    public Double getErrorFrames() {
        return errorFrames;
    }

    public void setErrorFrames(Double errorFrames) {
        this.errorFrames = errorFrames;
    }

    public Double getDumpedFrames() {
        return dumpedFrames;
    }

    public void setDumpedFrames(Double dumpedFrames) {
        this.dumpedFrames = dumpedFrames;
    }

    public Double getLinkFailures() {
        return linkFailures;
    }

    public void setLinkFailures(Double linkFailures) {
        this.linkFailures = linkFailures;
    }

    public Double getLossSignalCounter() {
        return lossSignalCounter;
    }

    public void setLossSignalCounter(Double lossSignalCounter) {
        this.lossSignalCounter = lossSignalCounter;
    }

    public Double getLossSyncCounter() {
        return lossSyncCounter;
    }

    public void setLossSyncCounter(Double lossSyncCounter) {
        this.lossSyncCounter = lossSyncCounter;
    }

    public Double getPrimitiveSeqProtocolErrCount() {
        return primitiveSeqProtocolErrCount;
    }

    public void setPrimitiveSeqProtocolErrCount(Double primitiveSeqProtocolErrCount) {
        this.primitiveSeqProtocolErrCount = primitiveSeqProtocolErrCount;
    }

    public Double getCrcErrors() {
        return crcErrors;
    }

    public void setCrcErrors(Double crcErrors) {
        this.crcErrors = crcErrors;
    }

    public Double getInvalidTransmissionWords() {
        return invalidTransmissionWords;
    }

    public void setInvalidTransmissionWords(Double invalidTransmissionWords) {
        this.invalidTransmissionWords = invalidTransmissionWords;
    }

    public Double getFramesToolShort() {
        return framesToolShort;
    }

    public void setFramesToolShort(Double framesToolShort) {
        this.framesToolShort = framesToolShort;
    }

    public Double getFramesToolLong() {
        return framesToolLong;
    }

    public void setFramesToolLong(Double framesToolLong) {
        this.framesToolLong = framesToolLong;
    }

    public Double getAddressErrors() {
        return addressErrors;
    }

    public void setAddressErrors(Double addressErrors) {
        this.addressErrors = addressErrors;
    }

    public Double getBufferCreditNotProvided() {
        return bufferCreditNotProvided;
    }

    public void setBufferCreditNotProvided(Double bufferCreditNotProvided) {
        this.bufferCreditNotProvided = bufferCreditNotProvided;
    }

    public Double getBufferCreditNotReceived() {
        return bufferCreditNotReceived;
    }

    public void setBufferCreditNotReceived(Double bufferCreditNotReceived) {
        this.bufferCreditNotReceived = bufferCreditNotReceived;
    }

    public Double getBbcreditZeroTime() {
        return bbcreditZeroTime;
    }

    public void setBbcreditZeroTime(Double bbcreditZeroTime) {
        this.bbcreditZeroTime = bbcreditZeroTime;
    }

    public Double getDelimiterErrors() {
        return delimiterErrors;
    }

    public void setDelimiterErrors(Double delimiterErrors) {
        this.delimiterErrors = delimiterErrors;
    }

    public Double getEncodingDisparityErrors() {
        return encodingDisparityErrors;
    }

    public void setEncodingDisparityErrors(Double encodingDisparityErrors) {
        this.encodingDisparityErrors = encodingDisparityErrors;
    }

    public Double getLinkResetsReceived() {
        return linkResetsReceived;
    }

    public void setLinkResetsReceived(Double linkResetsReceived) {
        this.linkResetsReceived = linkResetsReceived;
    }

    public Double getLinkResetsTransmitted() {
        return linkResetsTransmitted;
    }

    public void setLinkResetsTransmitted(Double linkResetsTransmitted) {
        this.linkResetsTransmitted = linkResetsTransmitted;
    }

    public Double getMulticastFramesReceived() {
        return multicastFramesReceived;
    }

    public void setMulticastFramesReceived(Double multicastFramesReceived) {
        this.multicastFramesReceived = multicastFramesReceived;
    }

    public Double getMulticastFramesTransmitted() {
        return multicastFramesTransmitted;
    }

    public void setMulticastFramesTransmitted(Double multicastFramesTransmitted) {
        this.multicastFramesTransmitted = multicastFramesTransmitted;
    }

    public Double getFbsyFrames() {
        return fbsyFrames;
    }

    public void setFbsyFrames(Double fbsyFrames) {
        this.fbsyFrames = fbsyFrames;
    }

    public Double getPbsyFrames() {
        return pbsyFrames;
    }

    public void setPbsyFrames(Double pbsyFrames) {
        this.pbsyFrames = pbsyFrames;
    }

    public Double getFrjtFrames() {
        return frjtFrames;
    }

    public void setFrjtFrames(Double frjtFrames) {
        this.frjtFrames = frjtFrames;
    }

    public Double getPrjtFrames() {
        return prjtFrames;
    }

    public void setPrjtFrames(Double prjtFrames) {
        this.prjtFrames = prjtFrames;
    }

    public Double getRxclass1Frames() {
        return rxclass1Frames;
    }

    public void setRxclass1Frames(Double rxclass1Frames) {
        this.rxclass1Frames = rxclass1Frames;
    }

    public Double getTxclass1Frames() {
        return txclass1Frames;
    }

    public void setTxclass1Frames(Double txclass1Frames) {
        this.txclass1Frames = txclass1Frames;
    }

    public Double getClass1Fbsy() {
        return class1Fbsy;
    }

    public void setClass1Fbsy(Double class1Fbsy) {
        this.class1Fbsy = class1Fbsy;
    }

    public Double getClass1Pbsy() {
        return class1Pbsy;
    }

    public void setClass1Pbsy(Double class1Pbsy) {
        this.class1Pbsy = class1Pbsy;
    }

    public Double getClass1Frjt() {
        return class1Frjt;
    }

    public void setClass1Frjt(Double class1Frjt) {
        this.class1Frjt = class1Frjt;
    }

    public Double getClass1Prjt() {
        return class1Prjt;
    }

    public void setClass1Prjt(Double class1Prjt) {
        this.class1Prjt = class1Prjt;
    }

    public Double getRxclass2Frames() {
        return rxclass2Frames;
    }

    public void setRxclass2Frames(Double rxclass2Frames) {
        this.rxclass2Frames = rxclass2Frames;
    }

    public Double getTxclass2Frames() {
        return txclass2Frames;
    }

    public void setTxclass2Frames(Double txclass2Frames) {
        this.txclass2Frames = txclass2Frames;
    }

    public Double getClass2Fbsy() {
        return class2Fbsy;
    }

    public void setClass2Fbsy(Double class2Fbsy) {
        this.class2Fbsy = class2Fbsy;
    }

    public Double getClass2Pbsy() {
        return class2Pbsy;
    }

    public void setClass2Pbsy(Double class2Pbsy) {
        this.class2Pbsy = class2Pbsy;
    }

    public Double getClass2Frjt() {
        return class2Frjt;
    }

    public void setClass2Frjt(Double class2Frjt) {
        this.class2Frjt = class2Frjt;
    }

    public Double getClass2Prjt() {
        return class2Prjt;
    }

    public void setClass2Prjt(Double class2Prjt) {
        this.class2Prjt = class2Prjt;
    }

    public Double getRxclass3Frames() {
        return rxclass3Frames;
    }

    public void setRxclass3Frames(Double rxclass3Frames) {
        this.rxclass3Frames = rxclass3Frames;
    }

    public Double getTxclass3Frames() {
        return txclass3Frames;
    }

    public void setTxclass3Frames(Double txclass3Frames) {
        this.txclass3Frames = txclass3Frames;
    }

    public Double getClass3FramesDiscarded() {
        return class3FramesDiscarded;
    }

    public void setClass3FramesDiscarded(Double class3FramesDiscarded) {
        this.class3FramesDiscarded = class3FramesDiscarded;
    }

    public Double getRxbroadcastFrames() {
        return rxbroadcastFrames;
    }

    public void setRxbroadcastFrames(Double rxbroadcastFrames) {
        this.rxbroadcastFrames = rxbroadcastFrames;
    }

    public Double getTxbroadcastFrames() {
        return txbroadcastFrames;
    }

    public void setTxbroadcastFrames(Double txbroadcastFrames) {
        this.txbroadcastFrames = txbroadcastFrames;
    }
}
